==> kadu_0.10.1.orig.tar.bz2: kadu-0.10.1/plugins/screenshot/screenshot-plugin.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "debug.h"
#include "exports.h"

#include "configuration/gui/screenshot-configuration-ui-handler.h"
#include "configuration/screen-shot-configuration.h"
#include "notify/screenshot-notification.h"
#include "screenshot-actions.h"

#include "screenshot.h"

#include "screenshot-plugin.h"

ScreenshotPlugin::~ScreenshotPlugin()
{
}

int ScreenshotPlugin::init(bool firstLoad)
{
	Q_UNUSED(firstLoad)

	kdebugf();

	ScreenshotActions::registerActions();
	ScreenShotConfiguration::createInstance();
	ScreenShotConfigurationUiHandler::registerConfigurationUi();
	ScreenshotNotification::registerNotifications();

	return 0;
}

void ScreenshotPlugin::done()
{
	kdebugf();

	ScreenshotActions::unregisterActions();
	ScreenShotConfiguration::destroyInstance();
	ScreenShotConfigurationUiHandler::unregisterConfigurationUi();
	ScreenshotNotification::unregisterNotifiactions();
}

Q_EXPORT_PLUGIN2(screenshot, ScreenshotPlugin)

==> kadu_0.11.2.orig.tar.bz2: kadu-0.11.2/plugins/screenshot/screenshot-plugin.cpp <==
/*
 * %kadu copyright begin%
 * Copyright 2011 Piotr Galiszewski (piotr.galiszewski@kadu.im)
 * Copyright 2004 Adrian Smarzewski (adrian@kadu.net)
 * Copyright 2007, 2008, 2010, 2011 Rafał Malinowski (rafal.przemyslaw.malinowski@gmail.com)
 * Copyright 2011 Bartosz Brachaczek (b.brachaczek@gmail.com)
 * Copyright 2004, 2006 Marcin Ślusarz (joi@kadu.net)
 * %kadu copyright end%
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

#include "debug.h"
#include "exports.h"

#include "configuration/gui/screenshot-configuration-ui-handler.h"
#include "configuration/screen-shot-configuration.h"
#include "gui/actions/screenshot-actions.h"
#include "notify/screenshot-notification.h"

#include "screenshot.h"

#include "screenshot-plugin.h"

ScreenshotPlugin::~ScreenshotPlugin()
{
}

int ScreenshotPlugin::init(bool firstLoad)
{
	Q_UNUSED(firstLoad)

	kdebugf();

	ScreenshotActions::registerActions();
	ScreenShotConfiguration::createInstance();
	ScreenShotConfigurationUiHandler::registerConfigurationUi();
	ScreenshotNotification::registerNotifications();

	return 0;
}

void ScreenshotPlugin::done()
{
	kdebugf();

	ScreenshotActions::unregisterActions();
	ScreenShotConfiguration::destroyInstance();
	ScreenShotConfigurationUiHandler::unregisterConfigurationUi();
	ScreenshotNotification::unregisterNotifiactions();
}

Q_EXPORT_PLUGIN2(screenshot, ScreenshotPlugin)
